@@ -11,7 +11,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import mock
+from unittest import mock
 
 from os_brick.initiator.connectors import fibre_channel_s390x
 from os_brick.initiator import linuxfc
@@ -32,9 +32,8 @@ class FibreChannelConnectorS390XTestCase(test_connector.ConnectorTestCase):
 
     @mock.patch.object(linuxfc.LinuxFibreChannelS390X, 'configure_scsi_device')
     def test_get_host_devices(self, mock_configure_scsi_device):
-        lun = 2
-        possible_devs = [(3, 5), ]
-        devices = self.connector._get_host_devices(possible_devs, lun)
+        possible_devs = [(3, 5, 2), ]
+        devices = self.connector._get_host_devices(possible_devs)
         mock_configure_scsi_device.assert_called_with(3, 5,
                                                       "0x0002000000000000")
         self.assertEqual(3, len(devices))
@@ -60,16 +59,17 @@ class FibreChannelConnectorS390XTestCase(test_connector.ConnectorTestCase):
         self.assertEqual(lunstring, "0x4020400a00000000")
 
     @mock.patch.object(fibre_channel_s390x.FibreChannelConnectorS390X,
-                       '_get_possible_devices', return_value=[(3, 5), ])
+                       '_get_possible_devices', return_value=[(3, 5, 2), ])
     @mock.patch.object(linuxfc.LinuxFibreChannelS390X, 'get_fc_hbas_info',
                        return_value=[])
     @mock.patch.object(linuxfc.LinuxFibreChannelS390X,
                        'deconfigure_scsi_device')
     def test_remove_devices(self, mock_deconfigure_scsi_device,
                             mock_get_fc_hbas_info, mock_get_possible_devices):
-        connection_properties = {'target_wwn': 5, 'target_lun': 2}
-        self.connector._remove_devices(connection_properties, devices=None)
+        connection_properties = {'targets': [5, 2]}
+        self.connector._remove_devices(connection_properties, devices=None,
+                                       device_info=None)
         mock_deconfigure_scsi_device.assert_called_with(3, 5,
                                                         "0x0002000000000000")
         mock_get_fc_hbas_info.assert_called_once_with()
-        mock_get_possible_devices.assert_called_once_with([], 5)
+        mock_get_possible_devices.assert_called_once_with([], [5, 2])
